@@ -69,11 +69,64 @@ text_extents_repr(PyObject *self) {
     return result;
 }
 
-static PyObject*
-text_extents_getattro (PyObject *self, PyObject *name) {
-    return Pycairo_tuple_getattro (self, KWDS, name);
+static PyObject *
+text_extents_get_x_bearing(PyObject *self, void *closure)
+{
+    PyObject *obj = PyTuple_GetItem (self, 0);
+    Py_XINCREF (obj);
+    return obj;
 }
 
+static PyObject *
+text_extents_get_y_bearing(PyObject *self, void *closure)
+{
+    PyObject *obj = PyTuple_GetItem (self, 1);
+    Py_XINCREF (obj);
+    return obj;
+}
+
+static PyObject *
+text_extents_get_width(PyObject *self, void *closure)
+{
+    PyObject *obj = PyTuple_GetItem (self, 2);
+    Py_XINCREF (obj);
+    return obj;
+}
+
+static PyObject *
+text_extents_get_height(PyObject *self, void *closure)
+{
+    PyObject *obj = PyTuple_GetItem (self, 3);
+    Py_XINCREF (obj);
+    return obj;
+}
+
+static PyObject *
+text_extents_get_x_advance(PyObject *self, void *closure)
+{
+    PyObject *obj = PyTuple_GetItem (self, 4);
+    Py_XINCREF (obj);
+    return obj;
+}
+
+static PyObject *
+text_extents_get_y_advance(PyObject *self, void *closure)
+{
+    PyObject *obj = PyTuple_GetItem (self, 5);
+    Py_XINCREF (obj);
+    return obj;
+}
+
+static PyGetSetDef text_cluster_getset[] = {
+    {"x_bearing", (getter)text_extents_get_x_bearing},
+    {"y_bearing", (getter)text_extents_get_y_bearing},
+    {"width", (getter)text_extents_get_width},
+    {"height", (getter)text_extents_get_height},
+    {"x_advance", (getter)text_extents_get_x_advance},
+    {"y_advance", (getter)text_extents_get_y_advance},
+    {NULL,},
+};
+
 PyTypeObject PycairoTextExtents_Type = {
     PyVarObject_HEAD_INIT(NULL, 0)
     "cairo.TextExtents",                /* tp_name */
@@ -91,7 +144,7 @@ PyTypeObject PycairoTextExtents_Type = {
     0,                                  /* tp_hash */
     0,                                  /* tp_call */
     0,                                  /* tp_str */
-    text_extents_getattro,              /* tp_getattro */
+    0,                                  /* tp_getattro */
     0,                                  /* tp_setattro */
     0,                                  /* tp_as_buffer */
     Py_TPFLAGS_DEFAULT,                 /* tp_flags */
@@ -104,7 +157,7 @@ PyTypeObject PycairoTextExtents_Type = {
     0,                                  /* tp_iternext */
     0,                                  /* tp_methods */
     0,                                  /* tp_members */
-    0,                                  /* tp_getset */
+    text_cluster_getset,                /* tp_getset */
     0,                                  /* tp_base */
     0,                                  /* tp_dict */
     0,                                  /* tp_descr_get */
